@@ -6,8 +6,8 @@ import sys
 
 import argparse
 
-from pymchelper.detector import ErrorEstimate
-from pymchelper.io import convertfrompattern, convertfromlist
+from pymchelper.estimator import ErrorEstimate
+from pymchelper.input_output import convertfrompattern, convertfromlist
 from pymchelper.writers.common import Converters
 from pymchelper.writers.plots import ImageWriter, PlotAxis
 
